@@ -648,23 +648,31 @@ function go_next_concerned()
     }
     return true;
 }
+/**
+ * @brief View the history of an account
+ * @param {type} p_value
+ * @param {type} dossier
+ * @returns {undefined}
+ */
 function view_history_account(p_value, dossier)
 {
     layer++;
     id = 'det' + layer;
     var popup = {'id': id, 'cssclass': 'inner_box', 'html': loading(), 'drag': true};
 
-    querystring = 'gDossier=' + dossier + '&act=de&pcm_val=' + p_value + '&div=' + id + "&l=" + layer;
-    add_div(popup);
+    var querystring={'gDossier':dossier,'act':'de','pcm_val':p_value,'div':id,'l':layer,'op':'history'};
+    waiting_box();
 
     var action = new Ajax.Request(
-            "ajax_history.php",
+            "ajax_misc.php",
             {
                 method: 'get',
                 parameters: querystring,
                 onFailure: error_box,
                 onSuccess: function (req, xml)
                 {
+                    remove_waiting_box();
+                    add_div(popup);
                     success_box(req, xml);
                     g(id).style.top = calcy(140 + (layer * 3)) + "px";
                 }
@@ -672,19 +680,32 @@ function view_history_account(p_value, dossier)
     );
 
 }
-
+/**
+ * @brief Change the view of account history
+ * @param {type} obj
+ * @returns {Boolean}
+ */
 function update_history_account(obj)
 {
     try {
-        var querystring = "l=" + obj.div + "&div=" + obj.div + "&gDossier=" + obj.gDossier + "&pcm_val=" + obj.pcm_val + "&ex=" + obj.select.options[obj.select.selectedIndex].text;
+        var querystring = {
+            "l" :obj.div ,
+            "div" :obj.div ,
+            "gDossier" : obj.gDossier,
+            "pcm_val" : obj.pcm_val ,
+            "ex" : obj.select.options[obj.select.selectedIndex].text,
+            "op":"history"
+        };
+        waiting_box();
         var action = new Ajax.Request(
-                "ajax_history.php",
+                "ajax_misc.php",
                 {
                     method: 'get',
                     parameters: querystring,
                     onFailure: error_box,
                     onSuccess: function (req, xml)
                     {
+                        remove_waiting_box();
                         success_box(req, xml);
                         g(obj.div).style.top = calcy(140 + (layer * 3)) + "px";
                     }
@@ -696,48 +717,66 @@ function update_history_account(obj)
 
     return false;
 }
-/*!\brief
+/*!\brief Change the view of card history
  * \param p_value f_id of the card
  */
-
 function view_history_card(p_value, dossier)
 {
     layer++;
     id = 'det' + layer;
-    var popup = {'id':
-                id, 'cssclass': 'inner_box'
-        , 'html':
-                loading(), 'drag':
-                true};
-    querystring = 'gDossier=' + dossier + '&act=de&f_id=' + p_value + '&div=' + id + "&l=" + layer;
-    add_div(popup);
+    var popup = {'id':id,
+                'cssclass': 'inner_box', 
+                'html':loading(), 
+                'drag':true};
+    var querystring = { 'gDossier' : dossier ,
+         'act':'de',
+         'f_id' : p_value , 
+         'div' : id ,
+          "l" : layer,
+          "op":"history"};
+    waiting_box();
     var action = new Ajax.Request(
-            "ajax_history.php",
+            "ajax_misc.php",
             {
                 method: 'get',
                 parameters: querystring,
                 onFailure: error_box,
                 onSuccess: function (req, xml)
                 {
+                    remove_waiting_box();
+                    add_div(popup);
                     success_box(req, xml);
                     g(id).style.top = calcy(140 + (layer * 3)) + "px";
                 }
             }
     );
 }
-
+/**
+ * @brief update history view after changing the exercice
+ * @param {type} obj
+ * @returns {Boolean}
+ */
 function update_history_card(obj)
 {
     try {
-        var querystring = "l=" + obj.div + "&div=" + obj.div + "&gDossier=" + obj.gDossier + "&f_id=" + obj.f_id + "&ex=" + obj.select.options[obj.select.selectedIndex].text;
+        var querystring = {
+            "l" : obj.div , 
+            "div" : obj.div ,
+            "gDossier" : obj.gDossier,
+            "f_id" : obj.f_id ,
+            "ex" : obj.select.options[obj.select.selectedIndex].text,
+            "op":"history"
+        };
+        waiting_box();
         var action = new Ajax.Request(
-                "ajax_history.php",
+                "ajax_misc.php",
                 {
                     method: 'get',
                     parameters: querystring,
                     onFailure: error_box,
                     onSuccess: function (req, xml)
                     {
+                        remove_waiting_box();
                         success_box(req, xml);
                         g(obj.div).style.top = calcy(140 + (layer * 3)) + "px";
                     }
@@ -758,9 +797,13 @@ function update_history_card(obj)
 function removeOperation(p_jr_id, dossier, div)
 {
     waiting_box();
-    var qs = "gDossier=" + dossier + "&act=rmop&div=" + div + "&jr_id=" + p_jr_id;
-    var action = new Ajax.Request(
-            "ajax_ledger.php",
+    var qs = { "gDossier" :  dossier ,
+        "op":"ledger",
+        "act":"rmop",
+        "div" : div ,
+        "jr_id" : p_jr_id};
+    new Ajax.Request(
+            "ajax_misc.php",
             {
                 method: 'get',
                 parameters: qs,
@@ -778,11 +821,12 @@ function removeOperation(p_jr_id, dossier, div)
 function reverseOperation(obj)
 {
     var qs = $(obj).serialize();
+    qs["op"]="ledger";
     g('ext' + obj.divname).style.display = 'none';
     g('bext' + obj.divname).style.display = 'none';
     waiting_box();
-    var action = new Ajax.Request(
-            "ajax_ledger.php",
+    new Ajax.Request(
+            "ajax_misc.php",
             {
                 method: 'get',
                 parameters: qs,
@@ -802,24 +846,27 @@ function reverseOperation(obj)
 function modifyOperation(p_value, dossier)
 {
     layer++;
-    var id = 'det' + layer;
+    var id_div = 'det' + layer;
     waiting_box();
-    var querystring = 'gDossier=' + dossier + '&act=de&jr_id=' + p_value + '&div=' + id;
-
+    var querystring = { "gDossier" :  dossier ,
+        "op":"ledger",
+        "act":"de",
+        "div" : id_div ,
+        "jr_id" : p_value};
     var action = new Ajax.Request(
-            "ajax_ledger.php",
+            "ajax_misc.php",
             {
                 method: 'get',
                 parameters: querystring,
                 onFailure: error_box,
                 onSuccess: function (xml, txt) {
-                    var popup = {'id': id, 'cssclass': 'inner_box'
+                    var popup = {'id': id_div, 'cssclass': 'inner_box'
                         , 'html': "", 'drag': true};
                     remove_waiting_box();
                     add_div(popup);
                     success_box(xml, txt);
-                    $(id).style.position = "absolute";
-                    $(id).style.top = calcy(100 + (layer * 3)) + "px";
+                    $(id_div).style.position = "absolute";
+                    $(id_div).style.top = calcy(100 + (layer * 3)) + "px";
                 }
             }
     );
@@ -835,12 +882,13 @@ function viewOperation(p_value, p_dossier)
 }
 function dropLink(p_dossier, p_div, p_jr_id, p_jr_id2)
 {
-    var querystring = 'gDossier=' + p_dossier;
-    querystring += '&div=' + p_div;
-    querystring += '&jr_id=' + p_jr_id;
-    querystring += '&act=rmr';
-    querystring += '&jr_id2=' + p_jr_id2;
-    var action = new Ajax.Request('ajax_ledger.php',
+    var querystring = { "gDossier" :  p_dossier ,
+        "op":"ledger",
+        "act":"rmr",
+        "div" : p_div ,
+        "jr_id" : p_jr_id,
+        "jr_id2" : p_jr_id2};
+    var action = new Ajax.Request('ajax_misc.php',
             {
                 method: 'get',
                 parameters: querystring,
@@ -998,13 +1046,15 @@ function op_save(obj)
         queryString += '&div=' + obj.whatdiv.value;
         var divid=obj.whatdiv.value;
         queryString += '&act=save';
+        queryString += '&op=ledger';
+        
         waiting_box();
         /*
          * Operation detail is in a new window
          */
         if (g('inpopup'))
         {
-            var action = new Ajax.Request('ajax_ledger.php',
+            var action = new Ajax.Request('ajax_misc.php',
                     {
                         method: 'post',
                         parameters: queryString,
@@ -1019,15 +1069,16 @@ function op_save(obj)
             /*
              *Operation is in a modal box 
              */
-            var action = new Ajax.Request('ajax_ledger.php',
+            var action = new Ajax.Request('ajax_misc.php',
                     {
                         method: 'post',
                         parameters: queryString,
                         onFailure: null,
                         onSuccess: function(req,json) {
-                            new Ajax.Request('ajax_ledger.php', {
+                            new Ajax.Request('ajax_misc.php', {
                                 parameters:{'gDossier':obj.gDossier.value,
                                          'act':'de',
+                                         'op':'ledger',
                                          'jr_id' :  jr_id,
                                          'div' :  divid},
                                 onSuccess:function(xml) {
@@ -1144,9 +1195,9 @@ function document_remove(p_dossier,p_div,p_jrid)
     smoke.confirm('Effacer ?', function (e) 
     {
         if (e) {
-            new Ajax.Request('ajax_ledger.php',
+            new Ajax.Request('ajax_misc.php',
             {
-                parameters:{"p_dossier":p_dossier,"div":p_div,"p_jrid":p_jrid,'act':'rmf'},
+                parameters:{"op":"ledger","gDossier":p_dossier,"div":p_div,"p_jrid":p_jrid,'act':'rmf'},
                 onSuccess : function(x) {
                     $('receipt'+p_div).innerHTML=x.responseText;
                 }
