@@ -51,7 +51,11 @@
           <TD>
   <?php 
   if  ($g_user->can_write_action($this->ag_id) == true ):
-    echo $ag_contact->search().$ag_contact->input();
+        if ( $ag_contact->extra != "" ):
+        echo $ag_contact->search().$ag_contact->input();
+      else:
+          echo _('Pas de catégorie de contact');
+      endif;
   endif;
             ?>
           </td>
